pub mod address;
pub mod dhcp_server;
mod types;

const BASE: &str = "rest/ip";
